/*  $Id: configdata.h,v 1.7 1999/03/07 15:41:31 src Exp $
 *
 *  extracted from INN version 2.0
 *
 *  $Log: configdata.h,v $
 *  Revision 1.7  1999/03/07 15:41:31  src
 *  Removed DBZ_VERSION from configuration
 *
 *  Revision 1.6  1998/09/14 06:13:51  src
 *  Picked RETSIGTYPE from config.h
 *
 *  Revision 1.5  1998/09/02 06:50:25  src
 *  NewsX version 1.0
 *
 *  Revision 1.4  1998/07/12 10:39:22  src
 */

#ifndef _CONFIGDATA_H
#define _CONFIGDATA_H

#include "common.h"
#include "proto.h"
#include "../config.h"

typedef int BOOL;
#ifndef TRUE
#define TRUE 1
#endif
#ifndef FALSE
#define FALSE 0
#endif
#ifndef NULL
#define NULL (0)
#endif

#define COMMENT_CHAR    '#'

/* BUG: defined where? */
#define SMBUF           256
#endif

